Interface for resources that require cleanup.
The main purpose of this interface is to be used with EffectHandler. If EffectHandler implements it, then Feature will dispose this handler.
But Feature itself also implements it, just because it can.
- Implementers
- Annotations
-
- @experimental
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> - Disposes of resources held by the implementing class.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited