dispose abstract method
Disposes of resources held by the implementing class.
This method should be used to release any resources, such as open streams, database connections, or event listeners.
Implementation
Future<void> dispose();
Disposes of resources held by the implementing class.
This method should be used to release any resources, such as open streams, database connections, or event listeners.
Future<void> dispose();