call abstract method

FutureOr<void> call(
  1. Effect effect,
  2. MsgEmitter<Msg> emit
)

Processes the given effect and optionally emits messages using emit.

This method may execute asynchronously or synchronously, depending on the effect's nature.

  • effect: The effect to process.
  • emit: A function to emit messages in response to the effect.

Implementation

FutureOr<void> call(Effect effect, MsgEmitter<Msg> emit);