handle abstract method
Defines the logic for processing the effect within the isolate.
effect: The effect to be processed.emit: A function to emit messages back to the main isolate.
Subclasses must override this method with their effect handling logic.
Implementation
FutureOr<void> handle(Effect effect, MsgEmitter<Msg> emit);