call abstract method
Processes the given effect and optionally emits messages using emit.
This method may execute asynchronously or synchronously, depending on the effect's nature.
effect: The effect to process.emit: A function to emit messages in response to the effect.
Implementation
FutureOr<void> call(Effect effect, MsgEmitter<Msg> emit);